@@ -119,7 +119,8 @@ class RTCRtpCapabilities:
 @dataclass
 class RTCRtcpFeedback:
     """
-    The :class:`RTCRtcpFeedback` dictionary provides information on RTCP feedback messages.
+    The :class:`RTCRtcpFeedback` dictionary provides information on RTCP feedback
+    messages.
     """
 
     type: str
