@@ -6,7 +6,7 @@ import random
 import threading
 import time
 from dataclasses import dataclass
-from typing import Dict, List, Optional, Set
+from typing import Callable, Dict, List, Optional, Set
 
 from av.frame import Frame
 
@@ -26,6 +26,7 @@ from .rtp import (
     RTCP_PSFB_APP,
     RTCP_PSFB_PLI,
     RTCP_RTPFB_NACK,
+    RTP_HISTORY_SIZE,
     AnyRtcpPacket,
     RtcpByePacket,
     RtcpPsfbPacket,
@@ -78,6 +79,9 @@ class NackGenerator:
         self.missing: Set[int] = set()
 
     def add(self, packet: RtpPacket) -> bool:
+        """
+        Mark a new packet as received, and deduce missing packets.
+        """
         missed = False
 
         if self.max_seq is None:
@@ -95,8 +99,23 @@ class NackGenerator:
         else:
             self.missing.discard(packet.sequence_number)
 
+        # limit number of tracked packets
+        self.truncate()
+
         return missed
 
+    def truncate(self) -> None:
+        """
+        Limit the number of missing packets we track.
+
+        Otherwise, the size of RTCP FB messages grows indefinitely.
+        """
+        if self.max_seq is not None:
+            min_seq = uint16_add(self.max_seq, -RTP_HISTORY_SIZE)
+            for seq in list(self.missing):
+                if uint16_gt(min_seq, seq):
+                    self.missing.discard(seq)
+
 
 class StreamStatistics:
     def __init__(self, clockrate: int) -> None:
@@ -273,6 +292,13 @@ class RTCRtpReceiver:
         self.__remote_streams: Dict[int, StreamStatistics] = {}
         self.__rtcp_ssrc: Optional[int] = None
 
+        # logging
+        self.__log_debug: Callable[..., None] = lambda *args: None
+        if logger.isEnabledFor(logging.DEBUG):
+            self.__log_debug = lambda msg, *args: logger.debug(
+                f"RTCRtpReceiver(%s) {msg}", self.__kind, *args
+            )
+
     @property
     def track(self) -> MediaStreamTrack:
         """
@@ -553,7 +579,7 @@ class RTCRtpReceiver:
         except ConnectionError:
             pass
 
-    async def _send_rtcp_nack(self, media_ssrc: int, lost) -> None:
+    async def _send_rtcp_nack(self, media_ssrc: int, lost: List[int]) -> None:
         """
         Send an RTCP packet to report missing RTP packets.
         """
@@ -585,6 +611,3 @@ class RTCRtpReceiver:
             self.__decoder_queue.put(None)
             self.__decoder_thread.join()
             self.__decoder_thread = None
-
-    def __log_debug(self, msg: str, *args) -> None:
-        logger.debug(f"RTCRtpReceiver(%s) {msg}", self.__kind, *args)
