@@ -14,5 +14,6 @@ class RTCSessionDescription:
     def __post_init__(self):
         if self.type not in {"offer", "pranswer", "answer", "rollback"}:
             raise ValueError(
-                f"'type' must be in ['offer', 'pranswer', 'answer', 'rollback'] (got '{self.type}')"
+                "'type' must be in ['offer', 'pranswer', 'answer', 'rollback'] "
+                f"(got '{self.type}')"
             )
