@@ -7,13 +7,17 @@ from aiortc.jitterbuffer import JitterFrame
 
 from .codecs import CodecTestCase
 
+# silence
+PCMA_PAYLOAD = b"\xd5" * 160
+PCMU_PAYLOAD = b"\xff" * 160
+
 
 class PcmaTest(CodecTestCase):
     def test_decoder(self):
         decoder = get_decoder(PCMA_CODEC)
         self.assertIsInstance(decoder, PcmaDecoder)
 
-        frames = decoder.decode(JitterFrame(data=b"\xd5" * 160, timestamp=0))
+        frames = decoder.decode(JitterFrame(data=PCMA_PAYLOAD, timestamp=0))
         self.assertEqual(len(frames), 1)
         frame = frames[0]
         self.assertEqual(frame.format.name, "s16")
@@ -35,7 +39,7 @@ class PcmaTest(CodecTestCase):
             layout="mono", sample_rate=8000, count=10
         ):
             payloads, timestamp = encoder.encode(frame)
-            self.assertEqual(payloads, [b"\xd5" * 160])
+            self.assertEqual(payloads, [PCMA_PAYLOAD])
             self.assertEqual(timestamp, frame.pts)
 
     def test_encoder_stereo_8khz(self):
@@ -46,7 +50,7 @@ class PcmaTest(CodecTestCase):
             layout="stereo", sample_rate=8000, count=10
         ):
             payloads, timestamp = encoder.encode(frame)
-            self.assertEqual(payloads, [b"\xd5" * 160])
+            self.assertEqual(payloads, [PCMA_PAYLOAD])
             self.assertEqual(timestamp, frame.pts)
 
     def test_encoder_stereo_48khz(self):
@@ -57,9 +61,18 @@ class PcmaTest(CodecTestCase):
             layout="stereo", sample_rate=48000, count=10
         ):
             payloads, timestamp = encoder.encode(frame)
-            self.assertEqual(payloads, [b"\xd5" * 160])
+            self.assertEqual(payloads, [PCMA_PAYLOAD])
             self.assertEqual(timestamp, frame.pts // 6)
 
+    def test_encoder_pack(self):
+        encoder = get_encoder(PCMA_CODEC)
+        self.assertTrue(isinstance(encoder, PcmaEncoder))
+
+        packet = self.create_packet(payload=PCMA_PAYLOAD, pts=1)
+        payloads, timestamp = encoder.pack(packet)
+        self.assertEqual(payloads, [PCMA_PAYLOAD])
+        self.assertEqual(timestamp, 8)
+
     def test_roundtrip(self):
         self.roundtrip_audio(PCMA_CODEC, output_layout="mono", output_sample_rate=8000)
 
@@ -74,7 +87,7 @@ class PcmuTest(CodecTestCase):
         decoder = get_decoder(PCMU_CODEC)
         self.assertIsInstance(decoder, PcmuDecoder)
 
-        frames = decoder.decode(JitterFrame(data=b"\xff" * 160, timestamp=0))
+        frames = decoder.decode(JitterFrame(data=PCMU_PAYLOAD, timestamp=0))
         self.assertEqual(len(frames), 1)
         frame = frames[0]
         self.assertEqual(frame.format.name, "s16")
@@ -93,7 +106,7 @@ class PcmuTest(CodecTestCase):
             layout="mono", sample_rate=8000, count=10
         ):
             payloads, timestamp = encoder.encode(frame)
-            self.assertEqual(payloads, [b"\xff" * 160])
+            self.assertEqual(payloads, [PCMU_PAYLOAD])
             self.assertEqual(timestamp, frame.pts)
 
     def test_encoder_stereo_8khz(self):
@@ -104,7 +117,7 @@ class PcmuTest(CodecTestCase):
             layout="stereo", sample_rate=8000, count=10
         ):
             payloads, timestamp = encoder.encode(frame)
-            self.assertEqual(payloads, [b"\xff" * 160])
+            self.assertEqual(payloads, [PCMU_PAYLOAD])
             self.assertEqual(timestamp, frame.pts)
 
     def test_encoder_stereo_48khz(self):
@@ -115,7 +128,7 @@ class PcmuTest(CodecTestCase):
             layout="stereo", sample_rate=48000, count=10
         ):
             payloads, timestamp = encoder.encode(frame)
-            self.assertEqual(payloads, [b"\xff" * 160])
+            self.assertEqual(payloads, [PCMU_PAYLOAD])
             self.assertEqual(timestamp, frame.pts // 6)
 
     def test_roundtrip(self):
