@@ -10,6 +10,7 @@ from .codecs import CodecTestCase
 OPUS_CODEC = RTCRtpCodecParameters(
     mimeType="audio/opus", clockRate=48000, channels=2, payloadType=100
 )
+OPUS_PAYLOAD = b"\xfc\xff\xfe"
 
 
 class OpusTest(CodecTestCase):
@@ -17,7 +18,7 @@ class OpusTest(CodecTestCase):
         decoder = get_decoder(OPUS_CODEC)
         self.assertIsInstance(decoder, OpusDecoder)
 
-        frames = decoder.decode(JitterFrame(data=b"\xfc\xff\xfe", timestamp=0))
+        frames = decoder.decode(JitterFrame(data=OPUS_PAYLOAD, timestamp=0))
         self.assertEqual(len(frames), 1)
         frame = frames[0]
         self.assertEqual(frame.format.name, "s16")
@@ -35,7 +36,7 @@ class OpusTest(CodecTestCase):
 
         # first frame
         payloads, timestamp = encoder.encode(frames[0])
-        self.assertEqual(payloads, [b"\xfc\xff\xfe"])
+        self.assertEqual(payloads, [OPUS_PAYLOAD])
         self.assertEqual(timestamp, 0)
 
         # second frame
@@ -50,7 +51,7 @@ class OpusTest(CodecTestCase):
 
         # first frame
         payloads, timestamp = encoder.encode(frames[0])
-        self.assertEqual(payloads, [b"\xfc\xff\xfe"])
+        self.assertEqual(payloads, [OPUS_PAYLOAD])
         self.assertEqual(timestamp, 0)
 
         # second frame
@@ -65,13 +66,22 @@ class OpusTest(CodecTestCase):
 
         # first frame
         payloads, timestamp = encoder.encode(frames[0])
-        self.assertEqual(payloads, [b"\xfc\xff\xfe"])
+        self.assertEqual(payloads, [OPUS_PAYLOAD])
         self.assertEqual(timestamp, 0)
 
         # second frame
         payloads, timestamp = encoder.encode(frames[1])
         self.assertEqual(timestamp, 960)
 
+    def test_encoder_pack(self):
+        encoder = get_encoder(OPUS_CODEC)
+        self.assertTrue(isinstance(encoder, OpusEncoder))
+
+        packet = self.create_packet(payload=OPUS_PAYLOAD, pts=1)
+        payloads, timestamp = encoder.pack(packet)
+        self.assertEqual(payloads, [OPUS_PAYLOAD])
+        self.assertEqual(timestamp, 48)
+
     def test_roundtrip(self):
         self.roundtrip_audio(
             OPUS_CODEC, output_layout="stereo", output_sample_rate=48000
